function varargout = Event_Triggered_Help(varargin)
% EVENT_TRIGGERED_HELP M-file for Event_Triggered_Help.fig
%      EVENT_TRIGGERED_HELP, by itself, creates a new EVENT_TRIGGERED_HELP or raises the existing
%      singleton*.
%
%      H = EVENT_TRIGGERED_HELP returns the handle to a new EVENT_TRIGGERED_HELP or the handle to
%      the existing singleton*.
%
%      EVENT_TRIGGERED_HELP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in EVENT_TRIGGERED_HELP.M with the given input arguments.
%
%      EVENT_TRIGGERED_HELP('Property','Value',...) creates a new EVENT_TRIGGERED_HELP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Event_Triggered_Help_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Event_Triggered_Help_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Event_Triggered_Help

% Last Modified by GUIDE v2.5 21-May-2006 22:27:47

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Event_Triggered_Help_OpeningFcn, ...
                   'gui_OutputFcn',  @Event_Triggered_Help_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Event_Triggered_Help is made visible.
function Event_Triggered_Help_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Event_Triggered_Help (see VARARGIN)

% Choose default command line output for Event_Triggered_Help
handles.output = hObject;


% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Event_Triggered_Help wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Event_Triggered_Help_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


% --- Executes on selection change in listbox1.
function listbox1_Callback(hObject, eventdata, handles)

% --- Executes during object creation, after setting all properties.
function listbox1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in Close.
function Close_Callback(hObject, eventdata, handles)
delete(gcf)


